@@ -18,6 +18,7 @@ import copy
 import json
 
 from apitools.base.py import encoding
+from googlecloudsdk.command_lib.compute.interconnects.attachments import flags
 from googlecloudsdk.core import log
 
 
@@ -109,6 +110,7 @@ class InterconnectAttachment(object):
       geneve_vni,
       default_appliance_ip_address,
       tunnel_endpoint_ip_address,
+      resource_manager_tags,
   ):
     """Make an interconnect attachment insert request."""
     interconnect_self_link = None
@@ -198,6 +200,10 @@ class InterconnectAttachment(object):
       attachment.l2Forwarding.defaultApplianceIpAddress = (
           default_appliance_ip_address
       )
+    if resource_manager_tags is not None:
+      attachment.params = flags.CreateInterconnectAttachmentParams(
+          self._messages, resource_manager_tags
+      )
 
     if validate_only is not None:
       return (self._client.interconnectAttachments, 'Insert',
@@ -225,7 +231,6 @@ class InterconnectAttachment(object):
       customer_router_ipv6_interface_id=None,
       labels=None,
       label_fingerprint=None,
-      multicast_enabled=None,
       candidate_cloud_router_ipv6_address=None,
       candidate_customer_router_ipv6_address=None,
       geneve_vni=None,
@@ -260,8 +265,6 @@ class InterconnectAttachment(object):
       interconnect_attachment.customerRouterIpv6InterfaceId = (
           customer_router_ipv6_interface_id
       )
-    if multicast_enabled is not None:
-      interconnect_attachment.multicastEnabled = multicast_enabled
     if candidate_cloud_router_ipv6_address is not None:
       interconnect_attachment.candidateCloudRouterIpv6Address = (
           candidate_cloud_router_ipv6_address
@@ -486,6 +489,7 @@ class InterconnectAttachment(object):
       default_appliance_ip_address=None,
       tunnel_endpoint_ip_address=None,
       supports_400g=False,
+      resource_manager_tags=None,
   ):
     """Create an interconnectAttachment."""
     if edge_availability_domain is not None:
@@ -549,6 +553,7 @@ class InterconnectAttachment(object):
             geneve_vni,
             default_appliance_ip_address,
             tunnel_endpoint_ip_address,
+            resource_manager_tags,
         )
     ]
     if not only_generate_request:
@@ -574,7 +579,6 @@ class InterconnectAttachment(object):
       customer_router_ipv6_interface_id=None,
       only_generate_request=False,
       mtu=None,
-      multicast_enabled=None,
       candidate_cloud_router_ipv6_address=None,
       candidate_customer_router_ipv6_address=None,
       geneve_vni=None,
@@ -614,7 +618,6 @@ class InterconnectAttachment(object):
             customer_router_ipv6_interface_id,
             labels,
             label_fingerprint,
-            multicast_enabled,
             candidate_cloud_router_ipv6_address,
             candidate_customer_router_ipv6_address,
             geneve_vni,
