@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2024 Google LLC. All Rights Reserved.
+# Copyright 2025 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -203,6 +203,28 @@ def AddMaxTopologyDistanceAndAcceleratorTopologyArgsForWorkloadPolicy(parser):
   )
 
 
+def AddAcceleratorTopologyModeArgs(parser):
+  """Set arguments for accelerator-topology-mode for workload policies and placement policies."""
+  choices = {
+      'AUTO_CONNECT': (
+          'This creates a static, pre-formed accelerator topology.'
+      ),
+      'PROVISION_ONLY': (
+          'The interconnected chips are connected on demand. At the time of'
+          ' VM creation, the chips are not connected.'
+      ),
+  }
+  parser.add_argument(
+      '--accelerator-topology-mode',
+      choices=choices,
+      type=arg_utils.ChoiceToEnumName,
+      help=(
+          'Defines the accelerator connection strategy for accelerator machine'
+          ' types like TPUs.'
+      ),
+  )
+
+
 def GetOnSourceDiskDeleteFlagMapper(messages):
   return arg_utils.ChoiceEnumMapper(
       '--on-source-disk-delete',
