@@ -120,10 +120,6 @@ _INFO = {
         api='meshconfig.googleapis.com',
         cmd_group='mesh',
     ),
-    'workloadmigration': Info(
-        display_name='Workload Migration',
-        cmd_group='workload-migration',
-    ),
     'namespaceactuation': Info(
         display_name='Namespace Actuation',
         cmd_group='namespaceactuation',
