@@ -1510,7 +1510,23 @@ def AddInputPayloadFormatArgs(parser):
   )
 
 
-def AddRetryPolicyArgs(parser):
+def AddTriggerRetryPolicyArgs(parser):
+  """Adds arguments for the trigger's retry policy."""
+  retry_policy_group = parser.add_group(help="""
+The retry policy configuration for the trigger.
+Can only be set for Cloud Run destinations.
+""")
+  retry_policy_group.add_argument(
+      '--max-retry-attempts',
+      type=int,
+      help=(
+          'The maximum number of delivery attempts. '
+          'The only valid value is 1.'
+      ),
+  )
+
+
+def AddPipelineRetryPolicyArgs(parser):
   """Adds arguments for the pipeline's retry policy."""
   retry_policy_group = parser.add_group(help="""
 The retry policy configuration for the pipeline.
@@ -1522,8 +1538,8 @@ If the max-retry-delay and min-retry-delay are set to the same value, then the d
       '--max-retry-attempts',
       type=int,
       help=(
-          'The maximum number of retry attempts. If not set, the default value'
-          ' is 5.'
+          'The maximum number of delivery attempts. If not set, the default'
+          ' value is 5.'
       ),
   )
   retry_policy_group.add_argument(
@@ -1777,70 +1793,3 @@ def AddLabelsArg(parser, help_text):
       type=arg_parsers.ArgDict(),
       metavar='KEY=VALUE',
   )
-
-
-def AddCreatePipelineResourceArgs(parser):
-  """Adds resource arguments for creating an Eventarc Pipeline."""
-  concept_parsers.ConceptParser(
-      [
-          presentation_specs.ResourcePresentationSpec(
-              'pipeline',
-              PipelineResourceSpec(),
-              'The pipeline to create.',
-              required=True,
-          ),
-          presentation_specs.ResourcePresentationSpec(
-              '--error-message-bus',
-              MessageBusResourceSpec(),
-              'The error message bus of the pipeline.',
-              required=False,
-              hidden=True,
-              flag_name_overrides={
-                  'location': '--error-message-bus-location',
-                  'project': '--error-message-bus-project',
-              },
-          ),
-      ],
-      command_level_fallthroughs={
-          '--error-message-bus.location': ['pipeline.location'],
-      },
-  ).AddToParser(parser)
-
-
-def AddUpdatePipelineResourceArgs(parser):
-  """Adds resource arguments for updating an Eventarc Pipeline."""
-  error_message_bus_group = parser.add_mutually_exclusive_group(
-      required=False, hidden=True
-  )
-  concept_parsers.ConceptParser(
-      [
-          presentation_specs.ResourcePresentationSpec(
-              'pipeline',
-              PipelineResourceSpec(),
-              'The pipeline to update.',
-              required=True,
-          ),
-          presentation_specs.ResourcePresentationSpec(
-              '--error-message-bus',
-              MessageBusResourceSpec(),
-              'The error message bus of the pipeline to update.',
-              required=False,
-              hidden=True,
-              group=error_message_bus_group,
-              flag_name_overrides={
-                  'location': '--error-message-bus-location',
-                  'project': '--error-message-bus-project',
-              },
-          ),
-      ],
-      command_level_fallthroughs={
-          '--error-message-bus.location': ['pipeline.location'],
-      },
-  ).AddToParser(parser)
-  error_message_bus_group.add_argument(
-      '--clear-error-message-bus',
-      action='store_true',
-      help='Clear the error message bus of the pipeline.',
-      required=False,
-      hidden=True,
-  )
