@@ -22,6 +22,7 @@ import abc
 
 from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope import base
+from googlecloudsdk.calliope.concepts import deps as deps_lib
 from googlecloudsdk.calliope.concepts import util
 from googlecloudsdk.command_lib.util.concepts import completers
 from googlecloudsdk.core.util import text
@@ -190,8 +191,7 @@ class ResourceInfo(ConceptInfo):
   def BuildFullFallthroughsMap(self):
     return self.concept_spec.BuildFullFallthroughsMap(
         self.attribute_to_args_map,
-        self.fallthroughs_map,
-        plural=self.plural)
+        self.fallthroughs_map)
 
   def GetHints(self, attribute_name):
     """Gets a list of string hints for how to set an attribute.
@@ -206,11 +206,7 @@ class ResourceInfo(ConceptInfo):
       A list of hints for its fallthroughs, including its primary arg if any.
     """
     fallthroughs = self.BuildFullFallthroughsMap().get(attribute_name, [])
-    hints = []
-    for f in fallthroughs:
-      if f.hint not in hints:
-        hints.append(f.hint)
-    return hints
+    return deps_lib.GetHints(fallthroughs)
 
   def GetGroupHelp(self):
     """Build group help for the argument group."""
@@ -236,9 +232,9 @@ class ResourceInfo(ConceptInfo):
           # This may be an error, but existence of fallthroughs should not be
           # enforced here.
           continue
-        hint = '\nTo set the `{}` attribute:{}.'.format(
-            attr_name,
-            ';'.join(hints))
+        hint = '\n\nTo set the `{}` attribute:{}.'.format(
+            attr_name, ';'.join(hints)
+        )
         description.append(hint)
     return ' '.join(description)
 
@@ -275,8 +271,9 @@ class ResourceInfo(ConceptInfo):
     hints = [
         '\n* {}'.format(hint) for hint in self.GetHints(attribute.name)]
     if hints:
-      hint = '\nTo set the `{}` attribute:{}.'.format(attribute.name,
-                                                      ';'.join(hints))
+      hint = '\n\nTo set the `{}` attribute:{}.'.format(
+          attribute.name, ';'.join(hints)
+      )
       help_text += hint
     return help_text.format(resource=expansion_name)
 
