@@ -45,13 +45,11 @@ from googlecloudsdk.core.credentials import exceptions as c_exceptions
 from googlecloudsdk.core.credentials import introspect as c_introspect
 from googlecloudsdk.core.util import files
 from oauth2client import client
-from oauth2client import service_account
-from oauth2client.contrib import gce as oauth2client_gce
 import six
 
 ADC_QUOTA_PROJECT_FIELD_NAME = 'quota_project_id'
 
-_REVOKE_URI = 'https://accounts.google.com/o/oauth2/revoke'
+_REVOKE_URI = 'https://oauth2.googleapis.com/revoke'
 
 UNKNOWN_CREDS_NAME = 'unknown'
 USER_ACCOUNT_CREDS_NAME = 'authorized_user'
@@ -97,16 +95,7 @@ def IsGoogleAuthGceCredentials(creds):
   return isinstance(creds, google_auth_compute_engine.Credentials)
 
 
-def _IsUserAccountCredentialsOauth2client(creds):
-  if CredentialType.FromCredentials(creds).is_user:
-    return True
-  if c_devshell.IsDevshellEnvironment():
-    return CredentialType.FromCredentials(creds) == CredentialType.GCE
-  else:
-    return False
-
-
-def _IsUserAccountCredentialsGoogleAuth(creds):
+def IsUserAccountCredentials(creds):
   if CredentialTypeGoogleAuth.FromCredentials(creds).is_user:
     return True
   if c_devshell.IsDevshellEnvironment():
@@ -116,27 +105,10 @@ def _IsUserAccountCredentialsGoogleAuth(creds):
     return False
 
 
-def IsUserAccountCredentials(creds):
-  if IsOauth2ClientCredentials(creds):
-    return _IsUserAccountCredentialsOauth2client(creds)
-  else:
-    return _IsUserAccountCredentialsGoogleAuth(creds)
-
-
-def IsOauth2clientP12AccountCredentials(creds):
-  return (CredentialType.FromCredentials(creds) ==
-          CredentialType.P12_SERVICE_ACCOUNT)
-
-
 def IsServiceAccountCredentials(creds):
-  if IsOauth2ClientCredentials(creds):
-    cred_type = CredentialType.FromCredentials(creds)
-    return cred_type in (CredentialType.SERVICE_ACCOUNT,
-                         CredentialType.P12_SERVICE_ACCOUNT)
-  else:
-    cred_type = CredentialTypeGoogleAuth.FromCredentials(creds)
-    return cred_type in (CredentialTypeGoogleAuth.SERVICE_ACCOUNT,
-                         CredentialTypeGoogleAuth.P12_SERVICE_ACCOUNT)
+  cred_type = CredentialTypeGoogleAuth.FromCredentials(creds)
+  return cred_type in (CredentialTypeGoogleAuth.SERVICE_ACCOUNT,
+                       CredentialTypeGoogleAuth.P12_SERVICE_ACCOUNT)
 
 
 def IsExternalAccountCredentials(creds):
@@ -170,14 +142,9 @@ def IsImpersonatedAccountCredentials(creds):
 def HasDefaultUniverseDomain(credentials):
   """Check if the given credential has default universe domain.
 
-  For google-auth credential, we check its universe_domain property. The
-  deprecated oauth2client credentials only work in default universe domain so
-  we return True (Note that they are no longer used in gcloud, but not yet
-  removed from the code base).
-
   Args:
-    credentials: google.auth.credentials.Credentials or
-      client.OAuth2Credentials, the credentials to be checked.
+    credentials: google.auth.credentials.Credentials,
+      the credentials to be checked.
 
   Returns:
     bool, Whether or not the given credential has default universe domain.
@@ -190,12 +157,29 @@ def HasDefaultUniverseDomain(credentials):
   return True
 
 
-def GetEffectiveTokenUri(cred_json, key='token_uri'):
+def GetDefaultTokenUri():
+  """Get default token URI for credential based on context aware settings."""
+  if properties.VALUES.context_aware.use_client_certificate.GetBool():
+    return properties.VALUES.auth.mtls_token_host.Get(required=True)
+  else:
+    return properties.VALUES.auth.token_host.Get(required=True)
+
+
+def GetEffectiveTokenUriFromCreds(cred_json, key='token_uri'):
+  """Get the effective token URI for the given credential."""
   if properties.VALUES.auth.token_host.IsExplicitlySet():
     return properties.VALUES.auth.token_host.Get()
-  if cred_json.get(key):
+  # If credentials JSON is provided and token_uri is present and not
+  # default/mTLS host, use the token_uri from the credentials JSON.
+  if (
+      cred_json.get(key)
+      and cred_json.get(key) != properties.VALUES.auth.DEFAULT_TOKEN_HOST
+      and cred_json.get(key) != properties.VALUES.auth.mtls_token_host.Get()
+  ):
     return cred_json.get(key)
-  return properties.VALUES.auth.DEFAULT_TOKEN_HOST
+  # Otherwise, the default or mTLS token host is used. The decision is driven by
+  # context_aware or use_client_certificate settings.
+  return GetDefaultTokenUri()
 
 
 def UseSelfSignedJwt(creds):
@@ -228,7 +212,8 @@ def UseSelfSignedJwt(creds):
 def EnableSelfSignedJwtIfApplicable(creds):
   if UseSelfSignedJwt(creds):
     creds._always_use_jwt_access = True  # pylint: disable=protected-access
-    creds._create_self_signed_jwt(None)  # pylint: disable=protected-access
+    if hasattr(creds, '_create_self_signed_jwt'):
+      creds._create_self_signed_jwt(None)  # pylint: disable=protected-access
 
 
 def WithAccount(creds, account):
@@ -470,33 +455,19 @@ class SqliteCredentialStore(CredentialStore):
         accounts_dict[account_id].append(universe_domain)
     return accounts_dict
 
-  def Load(self, account_id, use_google_auth=True):
+  def Load(self, account_id):
     """Load the credentials for the account_id.
 
     Args:
       account_id: str, The account_id of the credential to load.
-      use_google_auth: bool, Whether google-auth lib should be used. Default is
-        True.
 
     Returns:
-      google.auth.credentials.Credentials or client.OAuth2Credentials, The
-        loaded credentials.
+      google.auth.credentials.Credentials. The loaded credentials.
 
     Raises:
       googlecloudsdk.core.credentials.creds.InvalidCredentialsError: If problem
         happens when loading credentials.
     """
-    if not use_google_auth:
-      with self._cursor as cur:
-        cred_json = cur.Execute(
-            'SELECT value FROM "{}" WHERE account_id = ?'.format(
-                _CREDENTIAL_TABLE_NAME
-            ),
-            (account_id,),
-        ).fetchone()
-      if cred_json is None:
-        return None
-      return FromJson(cred_json[0])
 
     with self._cursor as cur:
       table = cur.Execute(
@@ -543,28 +514,19 @@ class SqliteCredentialStore(CredentialStore):
 
     Args:
       account_id: string, the account ID of the input credentials.
-      credentials: google.auth.credentials.Credentials or
-        client.OAuth2Credentials, the credentials to be stored.
+      credentials: google.auth.credentials.Credentials,
+        the credentials to be stored.
     """
-    if IsOauth2ClientCredentials(credentials):
-      value = ToJson(credentials)
-      self._Execute(
-          'REPLACE INTO "{}" (account_id, value) VALUES (?,?)'.format(
-              _CREDENTIAL_TABLE_NAME
-          ),
-          (account_id, value),
-      )
-    else:
-      value = ToJsonGoogleAuth(credentials)
-      formatted_account_id = _AccountIdFormatter.GetFormattedAccountId(
-          account_id, credentials
-      )
-      self._Execute(
-          'REPLACE INTO "{}" (account_id, value) VALUES (?,?)'.format(
-              _CREDENTIAL_TABLE_NAME
-          ),
-          (formatted_account_id, value),
-      )
+    value = ToJsonGoogleAuth(credentials)
+    formatted_account_id = _AccountIdFormatter.GetFormattedAccountId(
+        account_id, credentials
+    )
+    self._Execute(
+        'REPLACE INTO "{}" (account_id, value) VALUES (?,?)'.format(
+            _CREDENTIAL_TABLE_NAME
+        ),
+        (formatted_account_id, value),
+    )
 
   def Remove(self, account_id):
     formatted_account_id = _AccountIdFormatter.GetFormattedAccountId(
@@ -593,7 +555,8 @@ class AccessTokenCache(object):
   See go/gcloud-multi-universe-auth-cache section 3.2, 3.3 for more details.
   """
 
-  def __init__(self, store_file):
+  def __init__(self, store_file, cache_only_rapt=False):
+    self._cache_only_rapt = cache_only_rapt
     self._cursor = _SqlCursor(store_file)
     self._Execute(
         'CREATE TABLE IF NOT EXISTS "{}" '
@@ -649,6 +612,19 @@ class AccessTokenCache(object):
       rapt_token: str, The rapt token string to store.
       id_token: str, The ID token string to store.
     """
+    # This is used for the cases, when we want to cache the RAPT token but not
+    # the access token. For example, when we generate a scoped access token
+    # using the print-access-token command.
+    if self._cache_only_rapt:
+      result = self.Load(formatted_account_id)
+      if result:
+        access_token, token_expiry, _, id_token = result
+      else:
+        # If the access token is not stored in the cache, we will set it to
+        # None, as we only want to cache the RAPT token here.
+        access_token = None
+        token_expiry = None
+        id_token = None
     try:
       self._Execute(
           'REPLACE INTO "{}" '
@@ -680,61 +656,6 @@ class AccessTokenCache(object):
       log.warning('Could not delete access token from cache: {}'.format(str(e)))
 
 
-class AccessTokenStore(client.Storage):
-  """Oauth2client adapted for access token cache.
-
-  This class works with Oauth2client model where access token is part of
-  credential serialization format and get captured as part of that.
-  By extending client.Storage this class pretends to serialize credentials, but
-  only serializes access token.
-
-  When fetching the more recent credentials from the cache, this does not return
-  token_response, as it is now out of date.
-  """
-
-  def __init__(self, access_token_cache, account_id, credentials):
-    """Sets up token store for given acount.
-
-    Args:
-      access_token_cache: AccessTokenCache, cache for access tokens.
-      account_id: str, account for which token is stored.
-      credentials: oauth2client.client.OAuth2Credentials, they are auto-updated
-        with cached access token.
-    """
-    super(AccessTokenStore, self).__init__(lock=None)
-    self._access_token_cache = access_token_cache
-    self._account_id = account_id
-    self._credentials = credentials
-
-  def locked_get(self):
-    token_data = self._access_token_cache.Load(self._account_id)
-    if token_data:
-      access_token, token_expiry, rapt_token, id_token = token_data
-      self._credentials.access_token = access_token
-      self._credentials.token_expiry = token_expiry
-      if rapt_token is not None:
-        self._credentials.rapt_token = rapt_token
-      self._credentials.id_tokenb64 = id_token
-      self._credentials.token_response = None
-    return self._credentials
-
-  def locked_put(self, credentials):
-    if getattr(self._credentials, 'token_response'):
-      id_token = self._credentials.token_response.get('id_token', None)
-    else:
-      id_token = None
-
-    self._access_token_cache.Store(
-        self._account_id,
-        self._credentials.access_token,
-        self._credentials.token_expiry,
-        getattr(self._credentials, 'rapt_token', None),
-        id_token)
-
-  def locked_delete(self):
-    self._access_token_cache.Remove(self._account_id)
-
-
 class AccessTokenStoreGoogleAuth(object):
   """google-auth adapted for access token cache.
 
@@ -821,37 +742,9 @@ class AccessTokenStoreGoogleAuth(object):
     self._access_token_cache.Remove(self._formatted_account_id)
 
 
-def MaybeAttachAccessTokenCacheStore(credentials,
-                                     access_token_file=None):
-  """Attaches access token cache to given credentials if no store set.
-
-  Note that credentials themselves will not be persisted only access token. Use
-  this whenever access token caching is desired, yet credentials themselves
-  should not be persisted.
-
-  Args:
-    credentials: oauth2client.client.OAuth2Credentials.
-    access_token_file: str, optional path to use for access token storage.
-  Returns:
-    oauth2client.client.OAuth2Credentials, reloaded credentials.
-  """
-  if credentials.store is not None:
-    return credentials
-  account_id = getattr(credentials, 'service_account_email', None)
-  if not account_id:
-    account_id = hashlib.sha256(six.ensure_binary(
-        credentials.refresh_token)).hexdigest()
-
-  access_token_cache = AccessTokenCache(
-      access_token_file or config.Paths().access_token_db_path)
-  store = AccessTokenStore(access_token_cache, account_id, credentials)
-  credentials.set_store(store)
-  # Return from the store, which will reload credentials with access token info.
-  return store.get()
-
-
-def MaybeAttachAccessTokenCacheStoreGoogleAuth(credentials,
-                                               access_token_file=None):
+def MaybeAttachAccessTokenCacheStoreGoogleAuth(
+    credentials, access_token_file=None, cache_only_rapt=False
+):
   """Attaches access token cache to given credentials if no store set.
 
   Note that credentials themselves will not be persisted only access token. Use
@@ -866,6 +759,7 @@ def MaybeAttachAccessTokenCacheStoreGoogleAuth(credentials,
   Args:
     credentials: google.auth.credentials.Credentials.
     access_token_file: str, optional path to use for access token storage.
+    cache_only_rapt: bool, True to only cache RAPT token.
 
   Returns:
     google.auth.credentials.Credentials, reloaded credentials.
@@ -882,8 +776,10 @@ def MaybeAttachAccessTokenCacheStoreGoogleAuth(credentials,
     account_id = hashlib.sha256(six.ensure_binary(
         credentials.refresh_token)).hexdigest()
 
-  access_token_cache = AccessTokenCache(access_token_file or
-                                        config.Paths().access_token_db_path)
+  access_token_cache = AccessTokenCache(
+      access_token_file or config.Paths().access_token_db_path,
+      cache_only_rapt=cache_only_rapt,
+  )
   store = AccessTokenStoreGoogleAuth(access_token_cache, account_id,
                                      credentials)
   credentials = store.Get()
@@ -953,39 +849,33 @@ class CredentialStoreWithCache(CredentialStore):
     """Returns all the accounts stored in the cache."""
     return self._credential_store.GetAccounts()
 
-  def Load(self, account_id, use_google_auth=True):
+  def GetAccountsWithUniverseDomain(self):
+    """Returns all the accounts stored in the cache with their universe domain."""
+    return self._credential_store.GetAccountsWithUniverseDomain()
+
+  def Load(self, account_id):
     """Loads the credentials of account_id from the cache.
 
     Args:
       account_id: string, ID of the account to load.
-      use_google_auth: bool, True to load google-auth credentials if the type of
-        the credentials is supported by the cache. False to load oauth2client
-        credentials.
 
     Returns:
       1. None, if credentials are not found in the cache.
-      2. google.auth.credentials.Credentials, if use_google_auth is true.
-      3. client.OAuth2Credentials.
+      2. google.auth.credentials.Credentials
     """
     # Loads static credentials information from self._credential_store.
-    credentials = self._credential_store.Load(account_id, use_google_auth)
+    credentials = self._credential_store.Load(account_id)
     if credentials is None:
       return None
 
     # Loads short lived tokens from self._access_token_cache.
-    if IsOauth2ClientCredentials(credentials):
-      store = AccessTokenStore(self._access_token_cache, account_id,
-                               credentials)
-      credentials.set_store(store)
-      return store.get()
-    else:
-      store = AccessTokenStoreGoogleAuth(self._access_token_cache, account_id,
-                                         credentials)
-      credentials = store.Get()
+    store = AccessTokenStoreGoogleAuth(self._access_token_cache, account_id,
+                                       credentials)
+    credentials = store.Get()
 
-      # google-auth credentials do not support auto caching access token on
-      # credentials refresh. This logic needs to be implemented in gcloud.
-      return self._WrapCredentialsRefreshWithAutoCaching(credentials, store)
+    # google-auth credentials do not support auto caching access token on
+    # credentials refresh. This logic needs to be implemented in gcloud.
+    return self._WrapCredentialsRefreshWithAutoCaching(credentials, store)
 
   def Store(self, account_id, credentials):
     """Stores credentials into the cache with account of account_id.
@@ -993,19 +883,13 @@ class CredentialStoreWithCache(CredentialStore):
     Args:
       account_id: string, the account that will be associated with credentials
         in the cache.
-      credentials: google.auth.credentials.Credentials or
-        client.OAuth2Credentials, the credentials to be stored.
+      credentials: google.auth.credentials.Credentials,
+        the credentials to be stored.
     """
     # Stores short lived tokens to self._access_token_cache.
-    if IsOauth2ClientCredentials(credentials):
-      store = AccessTokenStore(self._access_token_cache, account_id,
-                               credentials)
-      credentials.set_store(store)
-      store.put(credentials)
-    else:
-      store = AccessTokenStoreGoogleAuth(self._access_token_cache, account_id,
-                                         credentials)
-      store.Put()
+    store = AccessTokenStoreGoogleAuth(self._access_token_cache, account_id,
+                                       credentials)
+    store.Put()
 
     # Stores static credentials information to self._credential_store.
     self._credential_store.Store(account_id, credentials)
@@ -1018,67 +902,27 @@ class CredentialStoreWithCache(CredentialStore):
     )
 
 
-def GetCredentialStore(store_file=None,
-                       access_token_file=None,
-                       with_access_token_cache=True):
+def GetCredentialStore(
+    store_file=None,
+    access_token_file=None,
+    cache_only_rapt=False,
+):
   """Constructs credential store.
 
   Args:
     store_file: str, optional path to use for storage. If not specified
       config.Paths().credentials_path will be used.
-
     access_token_file: str, optional path to use for access token storage. Note
       that some implementations use store_file to also store access_tokens, in
       which case this argument is ignored.
-    with_access_token_cache: bool, True to load a credential store with
-      auto caching for access tokens. False to load a credential store without
-      auto caching for access tokens.
+    cache_only_rapt: bool, True to only cache RAPT token.
 
   Returns:
     CredentialStore object.
   """
-  if with_access_token_cache:
-    return _GetSqliteStoreWithCache(store_file, access_token_file)
-  else:
-    return _GetSqliteStore(store_file)
-
-
-class CredentialType(enum.Enum):
-  """Enum of oauth2client credential types managed by gcloud."""
-
-  UNKNOWN = (0, UNKNOWN_CREDS_NAME, False, False)
-  USER_ACCOUNT = (1, USER_ACCOUNT_CREDS_NAME, True, True)
-  SERVICE_ACCOUNT = (2, SERVICE_ACCOUNT_CREDS_NAME, True, False)
-  P12_SERVICE_ACCOUNT = (3, P12_SERVICE_ACCOUNT_CREDS_NAME, True, False)
-  DEVSHELL = (4, DEVSHELL_CREDS_NAME, False, True)
-  GCE = (5, GCE_CREDS_NAME, False, False)
-
-  def __init__(self, type_id, key, is_serializable, is_user):
-    self.type_id = type_id
-    self.key = key
-    self.is_serializable = is_serializable
-    # True if this corresponds to a "user" or 3LO credential as opposed to a
-    # service account of some kind.
-    self.is_user = is_user
-
-  @staticmethod
-  def FromTypeKey(key):
-    for cred_type in CredentialType:
-      if cred_type.key == key:
-        return cred_type
-    return CredentialType.UNKNOWN
-
-  @staticmethod
-  def FromCredentials(creds):
-    if isinstance(creds, oauth2client_gce.AppAssertionCredentials):
-      return CredentialType.GCE
-    if isinstance(creds, service_account.ServiceAccountCredentials):
-      if getattr(creds, '_private_key_pkcs12', None) is not None:
-        return CredentialType.P12_SERVICE_ACCOUNT
-      return CredentialType.SERVICE_ACCOUNT
-    if getattr(creds, 'refresh_token', None) is not None:
-      return CredentialType.USER_ACCOUNT
-    return CredentialType.UNKNOWN
+  return _GetSqliteStoreWithCache(
+      store_file, access_token_file, cache_only_rapt
+  )
 
 
 class CredentialTypeGoogleAuth(enum.Enum):
@@ -1154,8 +998,7 @@ class CredentialTypeGoogleAuth(enum.Enum):
     if (isinstance(creds,
                    google_auth_external_account_authorized_user.Credentials)):
       return CredentialTypeGoogleAuth.EXTERNAL_ACCOUNT_AUTHORIZED_USER
-    # Import only when necessary to decrease the startup time. Move it to
-    # global once google-auth is ready to replace oauth2client.
+    # Import only when necessary to decrease the startup time.
     # pylint: disable=g-import-not-at-top
     from google.oauth2 import service_account as google_auth_service_account
     from googlecloudsdk.core.credentials import p12_service_account as google_auth_p12_service_account
@@ -1169,47 +1012,6 @@ class CredentialTypeGoogleAuth(enum.Enum):
     return CredentialTypeGoogleAuth.UNKNOWN
 
 
-def ToJson(credentials):
-  """Given Oauth2client credentials return library independent json for it."""
-  creds_type = CredentialType.FromCredentials(credentials)
-  if creds_type == CredentialType.USER_ACCOUNT:
-    creds_dict = {
-        'type': creds_type.key,
-        'client_id': credentials.client_id,
-        'client_secret': credentials.client_secret,
-        'refresh_token': credentials.refresh_token
-    }
-    # These fields are optionally serialized as they are not required for
-    # credentials to be usable, these are used by Oauth2client.
-    for field in ('id_token', 'invalid', 'revoke_uri', 'scopes',
-                  'token_response', 'token_uri', 'user_agent', 'rapt_token'):
-      value = getattr(credentials, field, None)
-      if value:
-        # Sets are not json serializable as is, so encode as a list.
-        if isinstance(value, set):
-          value = list(value)
-        creds_dict[field] = value
-
-  elif creds_type == CredentialType.SERVICE_ACCOUNT:
-    creds_dict = credentials.serialization_data
-  elif creds_type == CredentialType.P12_SERVICE_ACCOUNT:
-    # pylint: disable=protected-access
-    creds_dict = {
-        'client_email': credentials._service_account_email,
-        'type': creds_type.key,
-        # The base64 only deals with bytes. The encoded value is bytes but is
-        # known to be a safe ascii string. To serialize it, convert it to a
-        # text object.
-        'private_key': (base64.b64encode(credentials._private_key_pkcs12)
-                        .decode('ascii')),
-        'password': credentials._private_key_password
-    }
-  else:
-    raise UnknownCredentialsType(creds_type)
-  return json.dumps(creds_dict, sort_keys=True,
-                    indent=2, separators=(',', ': '))
-
-
 def ToJsonGoogleAuth(credentials):
   """Given google-auth credentials, return library independent json for it."""
   creds_type = CredentialTypeGoogleAuth.FromCredentials(credentials)
@@ -1360,45 +1162,6 @@ def ToDictGoogleAuth(credentials):
   return creds_dict
 
 
-def FromJson(json_value):
-  """Returns Oauth2client credentials from library independent json format."""
-  json_key = json.loads(json_value)
-  cred_type = CredentialType.FromTypeKey(json_key['type'])
-  json_key['token_uri'] = GetEffectiveTokenUri(json_key)
-  if cred_type == CredentialType.SERVICE_ACCOUNT:
-    cred = service_account.ServiceAccountCredentials.from_json_keyfile_dict(
-        json_key, scopes=config.CLOUDSDK_SCOPES)
-    cred.user_agent = cred._user_agent = config.CLOUDSDK_USER_AGENT
-  elif cred_type == CredentialType.USER_ACCOUNT:
-    cred = client.OAuth2Credentials(
-        access_token=None,
-        client_id=json_key['client_id'],
-        client_secret=json_key['client_secret'],
-        refresh_token=json_key['refresh_token'],
-        token_expiry=None,
-        token_uri=json_key.get('token_uri'),
-        user_agent=json_key.get('user_agent'),
-        revoke_uri=json_key.get('revoke_uri'),
-        id_token=json_key.get('id_token'),
-        token_response=json_key.get('token_response'),
-        scopes=json_key.get('scopes'),
-        token_info_uri=json_key.get('token_info_uri'),
-        rapt_token=json_key.get('rapt_token'),
-    )
-  elif cred_type == CredentialType.P12_SERVICE_ACCOUNT:
-    # pylint: disable=protected-access
-    cred = service_account.ServiceAccountCredentials._from_p12_keyfile_contents(
-        service_account_email=json_key['client_email'],
-        private_key_pkcs12=base64.b64decode(json_key['private_key']),
-        private_key_password=json_key['password'],
-        token_uri=json_key['token_uri'],
-        scopes=config.CLOUDSDK_SCOPES)
-    cred.user_agent = cred._user_agent = config.CLOUDSDK_USER_AGENT
-  else:
-    raise UnknownCredentialsType(json_key['type'])
-  return cred
-
-
 def FromJsonGoogleAuth(json_value):
   """Returns google-auth credentials from library independent json format.
 
@@ -1422,9 +1185,8 @@ def FromJsonGoogleAuth(json_value):
   json_key = json.loads(json_value)
   cred_type = CredentialTypeGoogleAuth.FromTypeKey(json_key['type'])
   if cred_type == CredentialTypeGoogleAuth.SERVICE_ACCOUNT:
-    json_key['token_uri'] = GetEffectiveTokenUri(json_key)
-    # Import only when necessary to decrease the startup time. Move it to
-    # global once google-auth is ready to replace oauth2client.
+    json_key['token_uri'] = GetEffectiveTokenUriFromCreds(json_key)
+    # Import only when necessary to decrease the startup time.
     # pylint: disable=g-import-not-at-top
     from google.oauth2 import service_account as google_auth_service_account
     # pylint: enable=g-import-not-at-top
@@ -1441,7 +1203,7 @@ def FromJsonGoogleAuth(json_value):
     EnableSelfSignedJwtIfApplicable(cred)
     return cred
   if cred_type == CredentialTypeGoogleAuth.P12_SERVICE_ACCOUNT:
-    json_key['token_uri'] = GetEffectiveTokenUri(json_key)
+    json_key['token_uri'] = GetEffectiveTokenUriFromCreds(json_key)
     from googlecloudsdk.core.credentials import p12_service_account  # pylint: disable=g-import-not-at-top
     cred = p12_service_account.CreateP12ServiceAccount(
         base64.b64decode(json_key['private_key']),
@@ -1517,9 +1279,8 @@ def FromJsonGoogleAuth(json_value):
     return WrapGoogleAuthExternalAccountRefresh(cred)
 
   if cred_type == CredentialTypeGoogleAuth.USER_ACCOUNT:
-    json_key['token_uri'] = GetEffectiveTokenUri(json_key)
-    # Import only when necessary to decrease the startup time. Move it to
-    # global once google-auth is ready to replace oauth2client.
+    json_key['token_uri'] = GetEffectiveTokenUriFromCreds(json_key)
+    # Import only when necessary to decrease the startup time.
     # pylint: disable=g-import-not-at-top
     from googlecloudsdk.core.credentials import google_auth_credentials as c_google_auth
     # pylint: enable=g-import-not-at-top
@@ -1572,8 +1333,11 @@ def WrapGoogleAuthExternalAccountRefresh(cred):
   return cred
 
 
-def _GetSqliteStoreWithCache(sqlite_credential_file=None,
-                             sqlite_access_token_file=None):
+def _GetSqliteStoreWithCache(
+    sqlite_credential_file=None,
+    sqlite_access_token_file=None,
+    cache_only_rapt=False,
+):
   """Get a sqlite-based Credential Store."""
 
   credential_store = _GetSqliteStore(sqlite_credential_file)
@@ -1581,7 +1345,9 @@ def _GetSqliteStoreWithCache(sqlite_credential_file=None,
   sqlite_access_token_file = (sqlite_access_token_file or
                               config.Paths().access_token_db_path)
   files.PrivatizeFile(sqlite_access_token_file)
-  access_token_cache = AccessTokenCache(sqlite_access_token_file)
+  access_token_cache = AccessTokenCache(
+      sqlite_access_token_file, cache_only_rapt
+  )
   return CredentialStoreWithCache(credential_store, access_token_cache)
 
 
@@ -1636,10 +1402,12 @@ class ADC(object):
   def __init__(self,
                credentials,
                impersonated_service_account=None,
-               delegates=None):
+               delegates=None,
+               scopes=None):
     self._credentials = credentials
     self._impersonated_service_account = impersonated_service_account
     self._delegates = delegates
+    self._scopes = scopes
 
   @property
   def is_user(self):
@@ -1651,7 +1419,8 @@ class ADC(object):
     """Json representation of the credentials for ADC."""
     return _ConvertCredentialsToADC(self._credentials,
                                     self._impersonated_service_account,
-                                    self._delegates)
+                                    self._delegates,
+                                    self._scopes)
 
   def DumpADCToFile(self, file_path=None):
     """Dumps the credentials to the ADC json file."""
@@ -1697,45 +1466,38 @@ def _DumpADCJsonToFile(adc, file_path):
   return os.path.abspath(file_path)
 
 
-def _ConvertOauth2ClientCredentialsToADC(credentials):
-  """Converts an oauth2client credentials to application default credentials."""
-  creds_type = CredentialType.FromCredentials(credentials)
-  if creds_type not in (CredentialType.USER_ACCOUNT,
-                        CredentialType.SERVICE_ACCOUNT):
-    raise ADCError('Cannot convert credentials of type {} to application '
-                   'default credentials.'.format(type(credentials)))
-  if creds_type == CredentialType.USER_ACCOUNT:
-    credentials = client.GoogleCredentials(
-        credentials.access_token, credentials.client_id,
-        credentials.client_secret, credentials.refresh_token,
-        credentials.token_expiry, credentials.token_uri, credentials.user_agent,
-        credentials.revoke_uri)
-  return credentials.serialization_data
-
-
-IMPERSONATION_TOKEN_URL = 'https://iamcredentials.googleapis.com/v1/projects/-/serviceAccounts/{}:generateAccessToken'
+IMPERSONATION_TOKEN_URL = 'https://iamcredentials.{}/v1/projects/-/serviceAccounts/{}:generateAccessToken'
 
 
 def _ConvertCredentialsToADC(credentials, impersonated_service_account,
-                             delegates):
+                             delegates, scopes=None):
   """Convert credentials with impersonation to a json dictionary."""
-  if IsOauth2ClientCredentials(credentials):
-    creds_dict = _ConvertOauth2ClientCredentialsToADC(credentials)
-  else:
-    creds_dict = _ConvertGoogleAuthCredentialsToADC(credentials)
+  creds_dict = _ConvertGoogleAuthCredentialsToADC(credentials)
 
   if not impersonated_service_account:
     return creds_dict
+
+  if hasattr(credentials, 'universe_domain'):
+    universe_domain = credentials.universe_domain
+  else:
+    universe_domain = properties.VALUES.core.universe_domain.default
+
   impersonated_creds_dict = {
       'source_credentials':
           creds_dict,
       'service_account_impersonation_url':
-          IMPERSONATION_TOKEN_URL.format(impersonated_service_account),
+          IMPERSONATION_TOKEN_URL.format(
+              universe_domain,
+              impersonated_service_account),
       'delegates':
           delegates or [],
       'type':
           'impersonated_service_account'
   }
+
+  if scopes:
+    impersonated_creds_dict['scopes'] = scopes
+
   return impersonated_creds_dict
 
 
