@@ -99,6 +99,12 @@ class Tool(proto.Message):
             Optional. Tool to support searching public
             web data, powered by Vertex AI Search and Sec4
             compliance.
+        parallel_ai_search (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.Tool.ParallelAiSearch):
+            Optional. If specified, Vertex AI will use
+            Parallel.ai to search for information to answer
+            user queries. The search results will be
+            grounded on Parallel.ai and presented to the
+            model for response generation
         code_execution (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.Tool.CodeExecution):
             Optional. CodeExecution tool type.
             Enables the model to execute code as part of
@@ -179,6 +185,44 @@ class Tool(proto.Message):
             enum='Tool.PhishBlockThreshold',
         )
 
+    class ParallelAiSearch(proto.Message):
+        r"""ParallelAiSearch tool type.
+        A tool that uses the Parallel.ai search engine for grounding.
+
+        Attributes:
+            api_key (str):
+                Optional. The API key for ParallelAiSearch.
+                If an API key is not provided, the system will
+                attempt to verify access by checking for an
+                active Parallel.ai subscription through the
+                Google Cloud Marketplace.
+                See
+                https://docs.parallel.ai/search/search-quickstart
+                for more details.
+            custom_configs (google.protobuf.struct_pb2.Struct):
+                Optional. Custom configs for ParallelAiSearch. This field
+                can be used to pass any parameter from the Parallel.ai
+                Search API. See the Parallel.ai documentation for the full
+                list of available parameters and their usage:
+                https://docs.parallel.ai/api-reference/search-beta/search
+                Currently only ``source_policy``, ``excerpts``,
+                ``max_results``, ``mode``, ``fetch_policy`` can be set via
+                this field. For example: { "source_policy": {
+                "include_domains": ["google.com", "wikipedia.org"],
+                "exclude_domains": ["example.com"] }, "fetch_policy": {
+                "max_age_seconds": 3600 } }
+        """
+
+        api_key: str = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        custom_configs: struct_pb2.Struct = proto.Field(
+            proto.MESSAGE,
+            number=3,
+            message=struct_pb2.Struct,
+        )
+
     class CodeExecution(proto.Message):
         r"""Tool that executes code generated by the model, and automatically
         returns the result to the model.
@@ -258,6 +302,11 @@ class Tool(proto.Message):
         number=6,
         message='EnterpriseWebSearch',
     )
+    parallel_ai_search: ParallelAiSearch = proto.Field(
+        proto.MESSAGE,
+        number=13,
+        message=ParallelAiSearch,
+    )
     code_execution: CodeExecution = proto.Field(
         proto.MESSAGE,
         number=4,
