@@ -77,7 +77,8 @@ class Create(base.CreateCommand):
       flags.AddDestNetworkScope(parser)
       flags.AddSrcNetworkType(parser)
       flags.AddDestNetworkType(parser)
-    if cls.ReleaseTrack() == base.ReleaseTrack.ALPHA:
+    if cls.ReleaseTrack() == base.ReleaseTrack.ALPHA or cls.ReleaseTrack(
+    ) == base.ReleaseTrack.BETA:
       flags.AddSrcNetworkContext(parser)
       flags.AddDestNetworkContext(parser)
 
@@ -250,7 +251,8 @@ class Create(base.CreateCommand):
               args.dest_network_type
           )
 
-    if self.ReleaseTrack() == base.ReleaseTrack.ALPHA:
+    if self.ReleaseTrack() == base.ReleaseTrack.ALPHA or self.ReleaseTrack(
+    ) == base.ReleaseTrack.BETA:
       if args.IsSpecified('src_network_context'):
         if not args.src_network_context:
           src_network_context = (
@@ -322,7 +324,8 @@ class Create(base.CreateCommand):
         traffic_direct = (
             holder.client.messages.FirewallPolicyRule.DirectionValueValuesEnum.EGRESS
         )
-    if self.ReleaseTrack() == base.ReleaseTrack.ALPHA:
+    if self.ReleaseTrack() == base.ReleaseTrack.ALPHA or self.ReleaseTrack(
+    ) == base.ReleaseTrack.BETA:
       matcher.srcNetworkContext = src_network_context
       matcher.destNetworkContext = dest_network_context
 
