@@ -21,16 +21,25 @@ from __future__ import unicode_literals
 from googlecloudsdk.calliope import base as calliope_base
 
 
-@calliope_base.ReleaseTracks(
-    calliope_base.ReleaseTrack.ALPHA, calliope_base.ReleaseTrack.BETA
-)
 class Configmanagement(calliope_base.Group):
-  """Manage Config Management feature.
-
-  Manage Config Sync using the Config Management feature. Policy Controller
-  users should use the separate command group: `gcloud container fleet
-  policycontroller`. Hierarchy Controller users should use
-  https://github.com/kubernetes-sigs/hierarchical-namespaces instead.
-  """
+  """Use the Config Management feature."""
 
   category = calliope_base.COMPUTE_CATEGORY
+  # Config Sync link breaks in docstring because it does not fit on 1 line.
+  # Pylint disallows long lines, even for a raw docstring, and the use of
+  # backslashes.
+  detailed_help = {
+      'DESCRIPTION': """
+Manage
+[Config Sync](https://docs.cloud.google.com/kubernetes-engine/config-sync/docs/how-to/installing-config-sync)
+using the Config Management feature.
+
+To manage Policy Controller, use `gcloud container fleet policycontroller`
+instead.
+
+Hierarchy Controller is no longer available to install. If Hierarchy Controller
+is still configured, Config Sync upgrades are blocked. To upgrade Config Sync,
+disable Hierarchy Controller following
+https://docs.cloud.google.com/kubernetes-engine/config-sync/docs/how-to/migrate-hierarchy-controller.
+"""
+  }
