@@ -21,11 +21,11 @@ from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
 
 
-@base.Hidden
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA,
+                    base.ReleaseTrack.GA)
 class WorkloadPoolProviderOperations(base.Group):
-  """Manage IAM WorkloadIdentityPoolProvider long running operations.
+  """Manage IAM workload identity pool provider long running operations.
 
-  Commands for managing IAM WorkloadIdentityPoolProvider long running
+  Commands for managing IAM workload identity pool provider long running
   operations.
   """
