@@ -314,6 +314,7 @@ class BetaUpdate(Update):
     flags.SERVICE_MESH_FLAG.AddToParser(parser)
     flags.AddIapFlag(parser)
     container_args = ContainerArgGroup(cls.ReleaseTrack())
+    container_args.AddArgument(flags.ReadinessProbeFlag())
     container_parser.AddContainerFlags(
         parser, container_args, cls.ReleaseTrack()
     )
@@ -338,7 +339,8 @@ class AlphaUpdate(BetaUpdate):
     flags.AddDescriptionFlag(parser)
     flags.SERVICE_MESH_FLAG.AddToParser(parser)
     flags.IDENTITY_FLAG.AddToParser(parser)
-    flags.ENABLE_WORKLOAD_CERTIFICATE_FLAG.AddToParser(parser)
+    flags.IDENTITY_CERTIFICATE_FLAG.AddToParser(parser)
+    flags.IDENTITY_TYPE_FLAG.AddToParser(parser)
     flags.MESH_DATAPLANE_FLAG.AddToParser(parser)
     flags.AddOverflowScalingFlag(parser)
     flags.AddCpuUtilizationFlag(parser)
