@@ -26,7 +26,7 @@ from googlecloudsdk.command_lib.tasks import parsers
 from googlecloudsdk.core import log
 
 
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
 class CreatePull(base.CreateCommand):
   """Create a pull queue.
 
@@ -39,6 +39,20 @@ class CreatePull(base.CreateCommand):
   For access, sign up here: https://goo.gl/Ya0AZd
   """
 
+  detailed_help = {
+      'DESCRIPTION':
+          """
+          {description}
+          """,
+      'EXAMPLES':
+          """
+          To create a Cloud Tasks pull queue:
+
+              $ {command} my-queue
+              --max-attempts=10 --max-retry-duration=10s
+         """,
+  }
+
   @staticmethod
   def Args(parser):
     flags.AddQueueResourceArg(parser, 'to create')
@@ -51,13 +65,24 @@ class CreatePull(base.CreateCommand):
     queue_ref = parsers.ParseQueue(args.queue, args.location)
     location_ref = parsers.ExtractLocationRefFromQueueRef(queue_ref)
     queue_config = parsers.ParseCreateOrUpdateQueueArgs(
-        args, constants.PULL_QUEUE, api.messages,
-        release_track=base.ReleaseTrack.ALPHA)
-    log.warning(constants.QUEUE_MANAGEMENT_WARNING)
-    create_response = queues_client.Create(
-        location_ref, queue_ref,
-        retry_config=queue_config.retryConfig,
-        rate_limits=queue_config.rateLimits,
-        pull_target=queue_config.pullTarget)
-    log.CreatedResource(queue_ref.Name(), 'queue')
+        args,
+        constants.PULL_QUEUE,
+        api.messages,
+        release_track=self.ReleaseTrack())
+    if self.ReleaseTrack() == base.ReleaseTrack.ALPHA:
+      create_response = queues_client.Create(
+          location_ref,
+          queue_ref,
+          retry_config=queue_config.retryConfig,
+          rate_limits=queue_config.rateLimits,
+          pull_target=queue_config.pullTarget)
+    else:
+      create_response = queues_client.Create(
+          location_ref,
+          queue_ref,
+          retry_config=queue_config.retryConfig,
+          rate_limits=queue_config.rateLimits,
+          queue_type=queue_config.type)
+    log.CreatedResource(
+        parsers.GetConsolePromptString(queue_ref.RelativeName()), 'queue')
     return create_response
